@@ -36,6 +36,9 @@
  * parametric type. */
 #define MVM_PARAMETERIZED_TYPE              32
 
+/* STable mode flag for a type that is not subject to repossession. */
+#define MVM_NEVER_REPOSSESS_TYPE            64
+
 /* HLL type roles. */
 #define MVM_HLL_ROLE_NONE                   0
 #define MVM_HLL_ROLE_INT                    1
@@ -86,6 +89,13 @@ struct MVMStorageSpec {
 #define MVM_STORAGE_SPEC_BP_INT         1
 #define MVM_STORAGE_SPEC_BP_NUM         2
 #define MVM_STORAGE_SPEC_BP_STR         3
+#define MVM_STORAGE_SPEC_BP_INT8        4
+#define MVM_STORAGE_SPEC_BP_INT16       5
+#define MVM_STORAGE_SPEC_BP_INT32       6
+#define MVM_STORAGE_SPEC_BP_UINT8       7
+#define MVM_STORAGE_SPEC_BP_UINT16      8
+#define MVM_STORAGE_SPEC_BP_UINT32      9
+#define MVM_STORAGE_SPEC_BP_UINT64     10
 
 /* can_box bit field values. */
 #define MVM_STORAGE_SPEC_CAN_BOX_INT    1
@@ -134,7 +144,15 @@ typedef enum {
     /* Note: if you're hunting for a flag, some day in the future when we
      * have used them all, this one is easy enough to eliminate by having the
      * tiny number of objects marked this way in a remembered set. */
-    MVM_CF_NEVER_REPOSSESS = 2048
+    MVM_CF_NEVER_REPOSSESS = 2048,
+
+    /* Has this item been chained into a gen2 freelist? This is only used in
+     * GC debug more. */
+    MVM_CF_DEBUG_IN_GEN2_FREE_LIST = 4096,
+
+    /* Is this object a nursery object that has been referenced from gen2?
+     * Used to promote it earlier. */
+    MVM_CF_REF_FROM_GEN2 = 8192,
 } MVMCollectableFlags;
 
 #ifdef MVM_USE_OVERFLOW_SERIALIZATION_INDEX
@@ -286,10 +304,10 @@ struct MVMSTable {
     /* Information - if any - about how we can turn something of this type
      * into a boolean. */
     MVMBoolificationSpec *boolification_spec;
-    
+
     /* The HLL that this type is owned by, if any. */
     MVMHLLConfig *hll_owner;
-    
+
     /* The role that the type plays in the HLL, if any. */
     MVMint64 hll_role;
 
@@ -384,11 +402,11 @@ struct MVMREPROps_Attribute {
         MVMint64 hint);
 
     /* Provided the attribute is a native integer of the architecture's atomic
-     * size, returns an AO_t * referencing it. This is only valid until the
-     * next safepoint. If rebless is called on the object, updates may be lost
-     * although memory safety must not be violated. */
+     * size or an object pointer, returns an AO_t * referencing it. This is only
+     * valid until the next safepoint. If rebless is called on the object,
+     * updates may be lost although memory safety must not be violated. */
     AO_t * (*attribute_as_atomic) (MVMThreadContext *tc, MVMSTable *st,
-        void *data, MVMObject *class_handle, MVMString *name);
+        void *data, MVMObject *class_handle, MVMString *name, MVMuint16 kind);
 };
 struct MVMREPROps_Boxing {
     /* Used with boxing. Sets an integer value, for representations that
@@ -473,11 +491,18 @@ struct MVMREPROps_Positional {
     void (*shift) (MVMThreadContext *tc, MVMSTable *st,
         MVMObject *root, void *data, MVMRegister *value, MVMuint16 kind);
 
+    /* Creates a slice of the source array (from start to end) and stores it
+     * within the destination array. If start or end is "-n", it will be
+     * translated into the nth position relative to the end of the array. */
+    void (*slice) (MVMThreadContext *tc, MVMSTable *st,
+        MVMObject *src, void *data, MVMObject *dest,
+        MVMint64 start, MVMint64 end);
+
     /* Splices the specified array into this one. Representations may optimize if
      * they know the type of the passed array, otherwise they should use the REPR
      * API. */
     void (*splice) (MVMThreadContext *tc, MVMSTable *st,
-        MVMObject *root, void *data, MVMObject *target_array,
+        MVMObject *root, void *data, MVMObject *from,
         MVMint64 offset, MVMuint64 elems);
 
     /* Multi-dimensional array read. */
@@ -515,6 +540,13 @@ struct MVMREPROps_Positional {
     /* Multi-dim version of as_atomic. */
     AO_t * (*pos_as_atomic_multidim) (MVMThreadContext *tc, MVMSTable *st, MVMObject *root,
         void *data, MVMint64 num_indices, MVMint64 *indices);
+
+    void (*write_buf) (MVMThreadContext *tc, MVMSTable *st,
+        MVMObject *root, void *data, char *from,
+        MVMint64 offset, MVMuint64 elems);
+
+    MVMint64 (*read_buf) (MVMThreadContext *tc, MVMSTable *st,
+        MVMObject *root, void *data, MVMint64 offset, MVMuint64 elems);
 };
 struct MVMREPROps_Associative {
     /* Gets the value at the specified key and places it in the passed
@@ -662,7 +694,8 @@ struct MVMREPROps {
 /* Some functions related to 6model core functionality. */
 MVM_PUBLIC MVMObject * MVM_6model_get_how(MVMThreadContext *tc, MVMSTable *st);
 MVM_PUBLIC MVMObject * MVM_6model_get_how_obj(MVMThreadContext *tc, MVMObject *obj);
-void MVM_6model_find_method(MVMThreadContext *tc, MVMObject *obj, MVMString *name, MVMRegister *res);
+void MVM_6model_find_method(MVMThreadContext *tc, MVMObject *obj, MVMString *name,
+    MVMRegister *res, MVMint64 throw_if_not_found);
 MVM_PUBLIC MVMObject * MVM_6model_find_method_cache_only(MVMThreadContext *tc, MVMObject *obj, MVMString *name);
 MVMint32 MVM_6model_find_method_spesh(MVMThreadContext *tc, MVMObject *obj, MVMString *name,
                                       MVMint32 ss_idx, MVMRegister *res);
@@ -682,3 +715,4 @@ MVM_STATIC_INLINE char *MVM_6model_get_debug_name(MVMThreadContext *tc, MVMObjec
 MVM_STATIC_INLINE char *MVM_6model_get_stable_debug_name(MVMThreadContext *tc, MVMSTable *stable) {
     return stable->debug_name ? stable->debug_name : "";
 }
+void MVM_6model_set_debug_name(MVMThreadContext *tc, MVMObject *type, MVMString *name);
