@@ -17,7 +17,6 @@
 #include "6model/reprs/MVMIter.h"
 #include "6model/reprs/MVMContext.h"
 #include "6model/reprs/SCRef.h"
-#include "6model/reprs/Lexotic.h"
 #include "6model/reprs/MVMCallCapture.h"
 #include "6model/reprs/P6bigint.h"
 #include "6model/reprs/NFA.h"
@@ -43,6 +42,8 @@
 #include "6model/reprs/NativeRef.h"
 #include "6model/reprs/MultiDimArray.h"
 #include "6model/reprs/Decoder.h"
+#include "6model/reprs/MVMSpeshLog.h"
+#include "6model/reprs/MVMStaticFrameSpesh.h"
 
 /* REPR related functions. */
 void MVM_repr_initialize_registry(MVMThreadContext *tc);
@@ -70,7 +71,7 @@ const MVMREPROps * MVM_repr_get_by_name(MVMThreadContext *tc, MVMString *name);
 #define MVM_REPR_ID_MVMIter                 15
 #define MVM_REPR_ID_MVMContext              16
 #define MVM_REPR_ID_SCRef                   17
-#define MVM_REPR_ID_Lexotic                 18
+#define MVM_REPR_ID_MVMSpeshLog             18
 #define MVM_REPR_ID_MVMCallCapture          19
 #define MVM_REPR_ID_P6bigint                20
 #define MVM_REPR_ID_NFA                     21
@@ -96,8 +97,9 @@ const MVMREPROps * MVM_repr_get_by_name(MVMThreadContext *tc, MVMString *name);
 #define MVM_REPR_ID_MultiDimArray           41
 #define MVM_REPR_ID_MVMCPPStruct            42
 #define MVM_REPR_ID_Decoder                 43
+#define MVM_REPR_ID_MVMStaticFrameSpesh     44
 
-#define MVM_REPR_CORE_COUNT                 44
+#define MVM_REPR_CORE_COUNT                 45
 #define MVM_REPR_MAX_COUNT                  64
 
 /* Default attribute functions for a REPR that lacks them. */
@@ -106,7 +108,8 @@ const MVMREPROps * MVM_repr_get_by_name(MVMThreadContext *tc, MVMString *name);
     MVM_REPR_DEFAULT_GET_ATTRIBUTE, \
     MVM_REPR_DEFAULT_BIND_ATTRIBUTE, \
     MVM_REPR_DEFAULT_HINT_FOR, \
-    MVM_REPR_DEFAULT_IS_ATTRIBUTE_INITIALIZED \
+    MVM_REPR_DEFAULT_IS_ATTRIBUTE_INITIALIZED, \
+    MVM_REPR_DEFAULT_ATTRIBUTE_AS_ATOMIC \
 }
 
 /* Default boxing functions for a REPR that lacks them. */
@@ -133,12 +136,15 @@ const MVMREPROps * MVM_repr_get_by_name(MVMThreadContext *tc, MVMString *name);
     MVM_REPR_DEFAULT_POP, \
     MVM_REPR_DEFAULT_UNSHIFT, \
     MVM_REPR_DEFAULT_SHIFT, \
+    MVM_REPR_DEFAULT_SLICE, \
     MVM_REPR_DEFAULT_SPLICE, \
     MVM_REPR_DEFAULT_AT_POS_MULTIDIM, \
     MVM_REPR_DEFAULT_BIND_POS_MULTIDIM, \
     MVM_REPR_DEFAULT_DIMENSIONS, \
     MVM_REPR_DEFAULT_SET_DIMENSIONS, \
-    MVM_REPR_DEFAULT_GET_ELEM_STORAGE_SPEC \
+    MVM_REPR_DEFAULT_GET_ELEM_STORAGE_SPEC, \
+    MVM_REPR_DEFAULT_POS_AS_ATOMIC, \
+    MVM_REPR_DEFAULT_POS_AS_ATOMIC_MULTIDIM \
 }
 
 /* Default associative functions for a REPR that lacks them. */
@@ -168,6 +174,7 @@ void MVM_REPR_DEFAULT_GET_ATTRIBUTE(MVMThreadContext *tc, MVMSTable *st, MVMObje
 void MVM_REPR_DEFAULT_BIND_ATTRIBUTE(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMObject *class_handle, MVMString *name, MVMint64 hint, MVMRegister value, MVMuint16 kind);
 MVMint64 MVM_REPR_DEFAULT_IS_ATTRIBUTE_INITIALIZED(MVMThreadContext *tc, MVMSTable *st, void *data, MVMObject *class_handle, MVMString *name, MVMint64 hint);
 MVMint64 MVM_REPR_DEFAULT_HINT_FOR(MVMThreadContext *tc, MVMSTable *st, MVMObject *class_handle, MVMString *name);
+AO_t * MVM_REPR_DEFAULT_ATTRIBUTE_AS_ATOMIC(MVMThreadContext *tc, MVMSTable *st, void *data, MVMObject *class_handle, MVMString *name, MVMuint16 kind);
 
 /* Default boxing REPR function for a REPR that lacks it. */
 void MVM_REPR_DEFAULT_SET_INT(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMint64 value);
@@ -188,11 +195,16 @@ void MVM_REPR_DEFAULT_PUSH(MVMThreadContext *tc, MVMSTable *st, MVMObject *root,
 void MVM_REPR_DEFAULT_POP(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMRegister *value, MVMuint16 kind);
 void MVM_REPR_DEFAULT_UNSHIFT(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMRegister value, MVMuint16 kind);
 void MVM_REPR_DEFAULT_SHIFT(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMRegister *value, MVMuint16 kind);
+void MVM_REPR_DEFAULT_SLICE(MVMThreadContext *tc, MVMSTable *st, MVMObject *src, void *data, MVMObject *dest, MVMint64 start, MVMint64 end);
 void MVM_REPR_DEFAULT_AT_POS_MULTIDIM(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMint64 num_indices, MVMint64 *indices, MVMRegister *value, MVMuint16 kind);
 void MVM_REPR_DEFAULT_BIND_POS_MULTIDIM(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMint64 num_indices, MVMint64 *indices, MVMRegister value, MVMuint16 kind);
 void MVM_REPR_DEFAULT_DIMENSIONS(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMint64 *num_dimensions, MVMint64 **dimensions);
 void MVM_REPR_DEFAULT_SET_DIMENSIONS(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMint64 num_dimensions, MVMint64 *dimensions);
 MVMStorageSpec MVM_REPR_DEFAULT_GET_ELEM_STORAGE_SPEC(MVMThreadContext *tc, MVMSTable *st);
+AO_t * MVM_REPR_DEFAULT_POS_AS_ATOMIC(MVMThreadContext *tc, MVMSTable *st, MVMObject *root,
+    void *data, MVMint64 index);
+AO_t * MVM_REPR_DEFAULT_POS_AS_ATOMIC_MULTIDIM(MVMThreadContext *tc, MVMSTable *st,
+    MVMObject *root, void *data, MVMint64 num_indices, MVMint64 *indices);
 
 /* Default associative indexing REPR function for a REPR that lacks it. */
 void MVM_REPR_DEFAULT_SPLICE(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *data, MVMObject *target_array, MVMint64 offset, MVMuint64 elems);
