@@ -7,14 +7,14 @@
  */
 
 /* Version information. */
-#define MVM_VERSION "2017.10"
-#define MVM_VERSION_MAJOR 2017
-#define MVM_VERSION_MINOR 10
+#define MVM_VERSION "2018.12"
+#define MVM_VERSION_MAJOR 2018
+#define MVM_VERSION_MINOR 12
 #define MVM_VERSION_PATCH 0
 
 /* Various compiler-specific pragmii. */
 #define MVM_NO_RETURN 
-#define MVM_NO_RETURN_GCC __attribute__((noreturn))
+#define MVM_NO_RETURN_ATTRIBUTE __attribute__((noreturn))
 #define MVM_FORMAT(X, Y, Z) __attribute__((format(X, Y, Z)))
 
 /* DLL interface definitions. */
@@ -24,8 +24,8 @@
 
 /* Set in case of big-endian sytems.
  * The default byte order is little-endian. */
-#if 0
-#define MVM_BIGENDIAN 0
+#if 1
+#define MVM_BIGENDIAN 1
 #endif
 
 /* pthread_yield() detection */
@@ -36,19 +36,19 @@
 /* How this compiler does static inline functions. */
 #define MVM_STATIC_INLINE static __inline__
 
-#if 1
+#if 0
 #define MVM_CAN_UNALIGNED_INT32
 #endif
 
-#if 1
+#if 0
 #define MVM_CAN_UNALIGNED_INT64
 #endif
 
-#if 1
+#if 0
 #define MVM_CAN_UNALIGNED_NUM64
 #endif
 
-#define MVM_PTR_SIZE 8
+#define MVM_PTR_SIZE 4
 
 
 #if 1
@@ -58,6 +58,12 @@
 /* Should we translate \n to \r\n on output? */
 #define MVM_TRANSLATE_NEWLINE_OUTPUT 0
 
-#define MVM_JIT_ARCH MVM_JIT_ARCH_X64
-#define MVM_JIT_PLATFORM MVM_JIT_PLATFORM_POSIX
+#define MVM_JIT_ARCH MVM_JIT_ARCH_NONE
+#define MVM_JIT_PLATFORM MVM_JIT_PLATFORM_NONE
 
+#define MVM_VECTORIZE_LOOP _Pragma ("clang loop vectorize(enable)")
+
+/* Branch condition compiler hints */
+#define MVM_LIKELY(condition) __builtin_expect(!!(condition), 1)
+#define MVM_UNLIKELY(condition) __builtin_expect(!!(condition), 0)
+#define MVM_EXPECT(condition, expection) __builtin_expect((condition), (expection))
