@@ -5,6 +5,7 @@ void MVM_coerce_istrue(MVMThreadContext *tc, MVMObject *obj, MVMRegister *res_re
 
 /* Stringification. */
 MVMString * MVM_coerce_i_s(MVMThreadContext *tc, MVMint64 i);
+MVMString * MVM_coerce_u_s(MVMThreadContext *tc, MVMuint64 i);
 MVMString * MVM_coerce_n_s(MVMThreadContext *tc, MVMnum64 n);
 void MVM_coerce_smart_stringify(MVMThreadContext *tc, MVMObject *obj, MVMRegister *res_reg);
 
@@ -22,3 +23,4 @@ void MVM_box_int(MVMThreadContext *tc, MVMint64 value, MVMObject *type, MVMRegis
 void MVM_box_num(MVMThreadContext *tc, MVMnum64 value, MVMObject *type, MVMRegister *dst);
 void MVM_box_str(MVMThreadContext *tc, MVMString *value, MVMObject *type, MVMRegister *dst);
 void MVM_box_uint(MVMThreadContext *tc, MVMuint64 value, MVMObject *type, MVMRegister *dst);
+MVMString * MVM_unbox_str(MVMThreadContext *tc, MVMObject *obj);
