@@ -84,6 +84,8 @@ struct MVMStringConsts {
     MVMString *translate_newlines;
     MVMString *platform_newline;
     MVMString *path;
+    MVMString *config;
+    MVMString *replacement;
 };
 
 /* An entry in the representations registry. */
@@ -203,6 +205,11 @@ struct MVMInstance {
     /* Fixed size allocator. */
     MVMFixedSizeAlloc *fsa;
 
+    /* Vector of memory to free at the next safepoint, and a mutex to guard
+     * access to it. */
+    MVM_VECTOR_DECL(void *, free_at_safepoint);
+    uv_mutex_t mutex_free_at_safepoint;
+
     /************************************************************************
      * Object system
      ************************************************************************/
@@ -227,12 +234,13 @@ struct MVMInstance {
      * the item is unresolved. Also, array of all SCs, used for the
      * index stored in object headers. When an SC goes away this is
      * simply nulled. That makes it a small memory leak if a lot of
-     * SCs are created and go away over time. */
+     * SCs are created and go away over time. The mutex protects all
+     * the weakhash and all SCs list. */
     MVMSerializationContextBody  *sc_weakhash;
-    uv_mutex_t                    mutex_sc_weakhash;
     MVMSerializationContextBody **all_scs;
     MVMuint32                     all_scs_next_idx;
     MVMuint32                     all_scs_alloc;
+    uv_mutex_t                    mutex_sc_registry;
 
     /* Mutex to serialize additions of type parameterizations. Global rather
      * than per STable, as this doesn't happen often. */
@@ -248,6 +256,7 @@ struct MVMInstance {
     /* Flag for if spesh (and certain spesh features) are enabled. */
     MVMint8 spesh_enabled;
     MVMint8 spesh_inline_enabled;
+    MVMint8 spesh_inline_log;
     MVMint8 spesh_osr_enabled;
     MVMint8 spesh_nodelay;
     MVMint8 spesh_blocking;
@@ -260,6 +269,9 @@ struct MVMInstance {
     /* Mutex taken when install specializations. */
     uv_mutex_t mutex_spesh_install;
 
+    /* The thread object representing the spesh thread */
+    MVMObject *spesh_thread;
+
     /* The concurrent queue used to send logs to spesh_thread, provided it
      * is enabled. */
     MVMObject *spesh_queue;
@@ -284,24 +296,21 @@ struct MVMInstance {
      ************************************************************************/
 
     /* Flag for if jit is enabled */
-    MVMint32 jit_enabled;
-
-    MVMint32 jit_expr_enabled;
+    MVMuint8 jit_enabled;
+    MVMuint8 jit_expr_enabled;
+    MVMuint8 jit_debug_enabled;
 
     /* bisection flags, to stop the JIT from using the expression compiler above
      * certain frame seq nr / basic blocks nrs, allowing a debugger to figure
      * out where a particular piece of code breaks */
     MVMint32 jit_expr_last_frame;
     MVMint32 jit_expr_last_bb;
-    /* File for JIT logging */
-    FILE *jit_log_fh;
+    /* File for JIT perf map logging */
+    FILE *jit_perf_map;
 
     /* Directory name for JIT bytecode dumps */
     char *jit_bytecode_dir;
 
-    /* File for map of frame information for bytecode dumps */
-    FILE *jit_bytecode_map;
-
     /* sequence number for JIT compiled frames */
     MVMint32 jit_seq_nr;
 
@@ -319,9 +328,9 @@ struct MVMInstance {
      * queue of tasks that need to be processed by the event loop thread
      * and an array of active tasks, for the purpose of keeping them GC
      * marked. */
-    MVMThreadContext *event_loop_thread;
-    uv_mutex_t        mutex_event_loop_start;
-    uv_sem_t          sem_event_loop_started;
+    MVMObject        *event_loop_thread;
+    uv_loop_t        *event_loop;
+    uv_mutex_t        mutex_event_loop;
     MVMObject        *event_loop_todo_queue;
     MVMObject        *event_loop_permit_queue;
     MVMObject        *event_loop_cancel_queue;
@@ -349,6 +358,12 @@ struct MVMInstance {
     /* Cache the environment hash */
     MVMObject      *env_hash;
 
+    /* Cache the signal array */
+    MVMObject      *sig_arr;
+
+    /* Flags indicating the signals available on the host system */
+    MVMuint64       valid_sigs;
+
     /************************************************************************
      * Caching and interning
      ************************************************************************/
@@ -362,7 +377,7 @@ struct MVMInstance {
     uv_mutex_t mutex_int_const_cache;
 
     /* Multi-dispatch cache addition mutex (additions are relatively
-     * rare, so little motivation to have it more fine-grained). */ 
+     * rare, so little motivation to have it more fine-grained). */
     uv_mutex_t mutex_multi_cache_add;
 
     /* Next type cache ID, to go in STable. */
@@ -489,10 +504,18 @@ struct MVMInstance {
      * Debugging
      ************************************************************************/
 
+    MVMDebugServerData *debugserver;
+
+    MVMuint32 speshworker_thread_id;
+
     /* Log file for dynamic var performance, if we're to log it. */
     FILE *dynvar_log_fh;
     MVMint64 dynvar_log_lasttime;
 
     /* Flag for if NFA debugging is enabled. */
     MVMint8 nfa_debug_enabled;
+
+    /* Hash Secrets which is used as the hash seed. This is to avoid denial of
+     * service type attacks. */
+    MVMuint64 hashSecrets[2];
 };
