@@ -44,9 +44,12 @@ struct MVMOpInfo {
     MVMuint16   num_operands;
     MVMuint8    pure;
     MVMuint8    deopt_point;
+    MVMuint8    may_cause_deopt;
     MVMuint8    logged;
     MVMuint8    no_inline;
     MVMuint8    jittivity;
+    MVMuint8    uses_hll;
+    MVMuint8    specializable;
     MVMuint8    operands[MVM_MAX_OPERANDS];
 };
 
@@ -92,6 +95,12 @@ struct MVMOpInfo {
 #define MVM_operand_uint64      (MVM_reg_uint64 << 3)
 #define MVM_operand_type_mask   (31 << 3)
 
+#ifdef MVM_BIGENDIAN
+#define MVM_SWITCHENDIAN 1
+#else
+#define MVM_SWITCHENDIAN 2
+#endif
+
 /* Functions. */
 void MVM_interp_run(MVMThreadContext *tc, void (*initial_invoke)(MVMThreadContext *, void *), void *invoke_data);
 MVM_PUBLIC void MVM_interp_enable_tracing();
