@@ -11,7 +11,10 @@ struct MVMJitGraph {
     MVMint32       obj_label_ofs;
 
     /* Sequence number for expr trees */
-    MVMuint32      expr_seq_nr;
+    MVMuint16      expr_seq_nr;
+
+    /* resultant JIT code is supports 'invokish' etc? */
+    MVMuint8       no_trampoline;
 
     /* All labeled things */
     MVM_VECTOR_DECL(void*, obj_labels);
@@ -57,10 +60,6 @@ struct MVMJitGuard {
 #define MVM_JIT_INFO_THROWISH 2
 
 typedef enum {
-    MVM_JIT_CONTROL_INVOKISH = 1,
-    MVM_JIT_CONTROL_DYNAMIC_LABEL,
-    MVM_JIT_CONTROL_THROWISH_PRE,
-    MVM_JIT_CONTROL_THROWISH_POST,
     MVM_JIT_CONTROL_BREAKPOINT,
 } MVMJitControlType;
 
@@ -107,10 +106,10 @@ typedef enum {
        cur_op. */
     MVM_JIT_REG_DYNIDX,
     MVM_JIT_DATA_LABEL,
-    MVM_JIT_SAVED_RV,
     /* The MVM_JIT_ARG_* types are used when the offset into the WORK array is
        not known yet, i.e. for ahead of time compiled native calls. */
     MVM_JIT_ARG_I64,
+    MVM_JIT_ARG_I64_RW,
     /* Pointers are passed as objects with CPointer representation, i.e. the
        actual pointer is part of the object's data. The MVM_JIT_ARG_PTR type
        unboxes the CPointer object and passes on the contained pointer */
@@ -120,8 +119,13 @@ typedef enum {
        happening as part of spesh, i.e. the offset of the args buffer in WORK
        is already known. */
     MVM_JIT_PARAM_I64,
+    MVM_JIT_PARAM_I64_RW,
     MVM_JIT_PARAM_PTR,
     MVM_JIT_PARAM_VMARRAY,
+    /* spesh slot value */
+    MVM_JIT_SPESH_SLOT_VALUE,
+    /* stack relative address */
+    MVM_JIT_STACK_VALUE,
 } MVMJitArgType;
 
 struct MVMJitCallArg {
@@ -155,6 +159,10 @@ typedef enum {
        we need to do the same as interp.c and address registers relative to
        cur_op. */
     MVM_JIT_RV_DYNIDX,
+    /* store pointer or vmnull */
+    MVM_JIT_RV_DEREF_OR_VMNULL,
+    /* store on stack with offset */
+    MVM_JIT_RV_TO_STACK,
 } MVMJitRVMode;
 
 
@@ -162,7 +170,6 @@ struct MVMJitCallC {
     void       *func_ptr;
     MVMJitCallArg  *args;
     MVMuint16   num_args;
-    MVMuint16  has_vargs;
     MVMJitRVMode rv_mode;
     MVMint16      rv_idx;
 };
@@ -173,9 +180,11 @@ struct MVMJitInvoke {
     MVMSpeshIns **arg_ins;
     MVMReturnType return_type;
     MVMint16      return_register;
-    MVMint16      code_register;
-    MVMint16      spesh_cand;
+    MVMuint32     code_register_or_name;
+    MVMint16      spesh_cand_or_sf_slot;
     MVMint8       is_fast;
+    MVMint8       is_resolve;
+    MVMuint32     resolve_offset;           /* Only for spesh resolve */
     MVMint32      reentry_label;
 };
 
@@ -194,6 +203,10 @@ struct MVMJitData {
     size_t    size;
 };
 
+struct MVMJitStackSlot {
+    MVMint16 slot;
+};
+
 /* Node types */
 typedef enum {
     MVM_JIT_NODE_PRIMITIVE,
@@ -206,7 +219,6 @@ typedef enum {
     MVM_JIT_NODE_CONTROL,
     MVM_JIT_NODE_DATA,
     MVM_JIT_NODE_EXPR_TREE,
-    MVM_JIT_NODE_SAVE_RV,
 } MVMJitNodeType;
 
 struct MVMJitNode {
@@ -223,6 +235,7 @@ struct MVMJitNode {
         MVMJitControl   control;
         MVMJitData      data;
         MVMJitExprTree *tree;
+        MVMJitStackSlot stack;
     } u;
 };
 
