@@ -64,6 +64,11 @@ struct MVMSpeshGraph {
      * don't typically don't update the array in specialized code. */
     MVMuint64 deopt_named_used_bit_field;
 
+    /* Deopt points that are considered to be always in use, even if they
+     * are not on a deopting instruction. */
+    MVMuint32 *always_retained_deopt_idxs;
+    MVMuint32 num_always_retained_deopt_idxs;
+
     /* Table of information about inlines, laid out in order of nesting
      * depth. Thus, going through the table in order and finding when we
      * are within the bounds will show up each call frame that needs to
@@ -105,6 +110,9 @@ struct MVMSpeshGraph {
 
     /* Did we specialize on the invocant type? */
     MVMuint8 specialized_on_invocant;
+
+    /* Do we set a dispatcher? */
+    MVMuint8 sets_dispatcher;
 };
 
 /* A temporary register, added to support transformations. */
@@ -113,6 +121,9 @@ struct MVMSpeshTemporary {
     MVMuint16 orig;
     MVMuint16 i;
 
+    /* The SSA index currently loaned out. */
+    MVMuint16 used_i;
+
     /* What kind of register is it? */
     MVMuint16 kind;
 
@@ -139,11 +150,15 @@ struct MVMSpeshBB {
     /* Dominance frontier set. */
     MVMSpeshBB **df;
 
+    /* Basic blocks that we may go to if we throw. */
+    MVMSpeshBB **handler_succ;
+
     /* Counts for the above, grouped together to avoid alignment holes. */
     MVMuint16    num_succ;
     MVMuint16    num_pred;
     MVMuint16    num_children;
     MVMuint16    num_df;
+    MVMuint16    num_handler_succ;
 
     /* The next basic block in original linear code order. */
     MVMSpeshBB *linear_next;
@@ -161,10 +176,16 @@ struct MVMSpeshBB {
     MVMuint32 initial_pc;
 
     /* Is this block an inlining of another one? */
-    MVMint16 inlined;
+    MVMint8 inlined;
+
+    /* Is this block an inline of one that may cause deopt? */
+    MVMint8 inlined_may_cause_deopt;
 
     /* Is this basic block part of a jump list? */
-    MVMint16 jumplist;
+    MVMint8 jumplist;
+
+    /* Is this basic block dead (removed due to being unreachable)? */
+    MVMint8 dead;
 };
 
 /* The SSA phi instruction. */
@@ -230,6 +251,7 @@ struct MVMSpeshAnn {
             MVMuint32 filename_string_index;
             MVMuint32 line_number;
         } lineno;
+        char *comment;
     } data;
 };
 
@@ -245,6 +267,8 @@ struct MVMSpeshAnn {
 #define MVM_SPESH_ANN_DEOPT_OSR     9
 #define MVM_SPESH_ANN_LINENO        10
 #define MVM_SPESH_ANN_LOGGED        11
+#define MVM_SPESH_ANN_DEOPT_SYNTH   12
+#define MVM_SPESH_ANN_COMMENT       4096
 
 /* Functions to create/destroy the spesh graph. */
 MVMSpeshGraph * MVM_spesh_graph_create(MVMThreadContext *tc, MVMStaticFrame *sf,
@@ -252,10 +276,20 @@ MVMSpeshGraph * MVM_spesh_graph_create(MVMThreadContext *tc, MVMStaticFrame *sf,
 MVMSpeshGraph * MVM_spesh_graph_create_from_cand(MVMThreadContext *tc, MVMStaticFrame *sf,
     MVMSpeshCandidate *cand, MVMuint32 cfg_only);
 MVMSpeshBB * MVM_spesh_graph_linear_prev(MVMThreadContext *tc, MVMSpeshGraph *g, MVMSpeshBB *search);
+void MVM_spesh_graph_grow_deopt_table(MVMThreadContext *tc, MVMSpeshGraph *g);
 void MVM_spesh_graph_add_deopt_annotation(MVMThreadContext *tc, MVMSpeshGraph *g,
     MVMSpeshIns *ins_node, MVMuint32 deopt_target, MVMint32 type);
 void MVM_spesh_graph_recompute_dominance(MVMThreadContext *tc, MVMSpeshGraph *g);
 void MVM_spesh_graph_mark(MVMThreadContext *tc, MVMSpeshGraph *g, MVMGCWorklist *worklist);
+void MVM_spesh_graph_describe(MVMThreadContext *tc, MVMSpeshGraph *g, MVMHeapSnapshotState *snapshot);
 void MVM_spesh_graph_destroy(MVMThreadContext *tc, MVMSpeshGraph *g);
 MVM_PUBLIC void * MVM_spesh_alloc(MVMThreadContext *tc, MVMSpeshGraph *g, size_t bytes);
 MVMOpInfo *get_phi(MVMThreadContext *tc, MVMSpeshGraph *g, MVMuint32 nrargs);
+
+MVM_PUBLIC void MVM_spesh_graph_add_comment(MVMThreadContext *tc, MVMSpeshGraph *g,
+    MVMSpeshIns *ins, const char *fmt, ...);
+
+MVM_STATIC_INLINE MVMuint32 MVM_spesh_is_inc_dec_op(MVMuint16 opcode) {
+    return opcode == MVM_OP_inc_i || opcode == MVM_OP_dec_i ||
+           opcode == MVM_OP_inc_u || opcode == MVM_OP_dec_u;
+}
