@@ -6,7 +6,11 @@
 #define MVM_encoding_type_utf16         4
 #define MVM_encoding_type_windows1252   5
 #define MVM_encoding_type_utf8_c8       6
-#define MVM_encoding_type_MAX           6
+#define MVM_encoding_type_windows1251   7
+#define MVM_encoding_type_shiftjis      8
+#define MVM_encoding_type_utf16le       9
+#define MVM_encoding_type_utf16be      10
+#define MVM_encoding_type_MAX          10
 #define ENCODING_VALID(enc) \
     (((enc) >= MVM_encoding_type_MIN && (enc) <= MVM_encoding_type_MAX) \
     || (MVM_exception_throw_adhoc(tc, "invalid encoding type flag: %d", (enc)),1))
@@ -57,7 +61,18 @@ MVM_STATIC_INLINE MVMuint32 MVM_string_codes(MVMThreadContext *tc, MVMString *s)
     }
     return codes;
 }
-
+MVM_STATIC_INLINE int MVM_string_buf32_can_fit_into_8bit(MVMGrapheme32 *active_blob, MVMStringIndex blob_len) {
+    MVMStringIndex i;
+    MVMGrapheme32 val = 0;
+    MVM_VECTORIZE_LOOP
+    for (i = 0; i  < blob_len; i++) {
+        /* This could be written val |= ..., but GCC 7 doesn't recognize the
+         * operation as ossociative unless we use a temp variable (clang has no issue). */
+        MVMGrapheme32 val2 = ((active_blob[i] & 0xffffff80) + 0x80) & (0xffffff80-1);
+        val |= val2;
+    }
+    return val ? 0 : 1;
+}
 MVMGrapheme32 MVM_string_get_grapheme_at_nocheck(MVMThreadContext *tc, MVMString *a, MVMint64 index);
 MVMint64 MVM_string_equal(MVMThreadContext *tc, MVMString *a, MVMString *b);
 MVMint64 MVM_string_index(MVMThreadContext *tc, MVMString *haystack, MVMString *needle, MVMint64 start);
@@ -87,7 +102,10 @@ MVMString * MVM_string_fc(MVMThreadContext *tc, MVMString *s);
 MVMString * MVM_string_decode(MVMThreadContext *tc, const MVMObject *type_object, char *Cbuf, MVMint64 byte_length, MVMint64 encoding_flag);
 char * MVM_string_encode(MVMThreadContext *tc, MVMString *s, MVMint64 start, MVMint64 length, MVMuint64 *output_size, MVMint64 encoding_flag, MVMString *replacement, MVMint32 translate_newlines);
 MVMObject * MVM_string_encode_to_buf(MVMThreadContext *tc, MVMString *s, MVMString *enc_name, MVMObject *buf, MVMString *replacement);
+MVMObject * MVM_string_encode_to_buf_config(MVMThreadContext *tc, MVMString *s, MVMString *enc_name, MVMObject *buf, MVMString *replacement, MVMint64 bitmap);
 MVMString * MVM_string_decode_from_buf(MVMThreadContext *tc, MVMObject *buf, MVMString *enc_name);
+MVMString * MVM_string_decode_from_buf_config(MVMThreadContext *tc, MVMObject *buf,
+        MVMString *enc_name, MVMString *replacement, MVMint64 bitmap);
 MVMObject * MVM_string_split(MVMThreadContext *tc, MVMString *separator, MVMString *input);
 MVMString * MVM_string_join(MVMThreadContext *tc, MVMString *separator, MVMObject *input);
 MVMint64 MVM_string_char_at_in_string(MVMThreadContext *tc, MVMString *a, MVMint64 offset, MVMString *b);
@@ -105,20 +123,22 @@ MVMint64 MVM_string_compare(MVMThreadContext *tc, MVMString *a, MVMString *b);
 MVMString * MVM_string_bitand(MVMThreadContext *tc, MVMString *a, MVMString *b);
 MVMString * MVM_string_bitor(MVMThreadContext *tc, MVMString *a, MVMString *b);
 MVMString * MVM_string_bitxor(MVMThreadContext *tc, MVMString *a, MVMString *b);
-void MVM_string_cclass_init(MVMThreadContext *tc);
 MVMint64 MVM_string_is_cclass(MVMThreadContext *tc, MVMint64 cclass, MVMString *s, MVMint64 offset);
 MVMint64 MVM_string_find_cclass(MVMThreadContext *tc, MVMint64 cclass, MVMString *s, MVMint64 offset, MVMint64 count);
 MVMint64 MVM_string_find_not_cclass(MVMThreadContext *tc, MVMint64 cclass, MVMString *s, MVMint64 offset, MVMint64 count);
 MVMuint8 MVM_string_find_encoding(MVMThreadContext *tc, MVMString *name);
 MVMString * MVM_string_chr(MVMThreadContext *tc, MVMint64 cp);
+MVMint64 MVM_string_grapheme_is_cclass(MVMThreadContext *tc, MVMint64 cclass, MVMGrapheme32 g);
 void MVM_string_compute_hash_code(MVMThreadContext *tc, MVMString *s);
+MVMString * MVM_string_ascii_from_buf_nocheck(MVMThreadContext *tc, MVMGrapheme8 *buf, MVMStringIndex len);
+char * MVM_string_encoding_cname(MVMThreadContext *tc, MVMint64 encoding);
 /* If MVM_DEBUG_NFG is 1, calls to NFG_CHECK will re_nfg the given string
  * and compare num_graphs before and after the normalization.
- * If it is different debug information will be printed out.
-#define MVM_DEBUG_NFG 1 */
+ * If it is different debug information will be printed out.*/
+#define MVM_DEBUG_NFG 0
 /* MVM_DEBUG_NFG_STRICT does as above but does not only rely on num_graphs. It
- * always checks every grapheme manually. Slower. (requires MVM_DEBUG_NFG)
-#define MVM_DEBUG_NFG_STRICT 0 */
+ * always checks every grapheme manually. Slower. (requires MVM_DEBUG_NFG)*/
+#define MVM_DEBUG_NFG_STRICT 0
 #if MVM_DEBUG_NFG
 void NFG_check (MVMThreadContext *tc, MVMString *orig, char *varname);
 void NFG_check_concat (MVMThreadContext *tc, MVMString *result, MVMString *a, MVMString *b, char *varname);
