@@ -125,7 +125,6 @@ typedef struct MVMSemaphoreBody MVMSemaphoreBody;
 typedef struct MVMConcBlockingQueue MVMConcBlockingQueue;
 typedef struct MVMConcBlockingQueueBody MVMConcBlockingQueueBody;
 typedef struct MVMConcBlockingQueueNode MVMConcBlockingQueueNode;
-typedef struct MVMConcBlockingQueueLocks MVMConcBlockingQueueLocks;
 typedef struct MVMObject MVMObject;
 typedef struct MVMObjectId MVMObjectId;
 typedef struct MVMObjectStooge MVMObjectStooge;
@@ -177,6 +176,10 @@ typedef struct MVMSpeshIterator MVMSpeshIterator;
 typedef struct MVMSpeshLog MVMSpeshLog;
 typedef struct MVMSpeshLogBody MVMSpeshLogBody;
 typedef struct MVMSpeshLogEntry MVMSpeshLogEntry;
+typedef struct MVMSpeshPluginState MVMSpeshPluginState;
+typedef struct MVMSpeshPluginPosition MVMSpeshPluginPosition;
+typedef struct MVMSpeshPluginGuardSet MVMSpeshPluginGuardSet;
+typedef struct MVMSpeshPluginGuard MVMSpeshPluginGuard;
 typedef struct MVMSpeshStats MVMSpeshStats;
 typedef struct MVMSpeshStatsByCallsite MVMSpeshStatsByCallsite;
 typedef struct MVMSpeshStatsByType MVMSpeshStatsByType;
@@ -185,6 +188,7 @@ typedef struct MVMSpeshStatsByOffset MVMSpeshStatsByOffset;
 typedef struct MVMSpeshStatsTypeCount MVMSpeshStatsTypeCount;
 typedef struct MVMSpeshStatsInvokeCount MVMSpeshStatsInvokeCount;
 typedef struct MVMSpeshStatsTypeTupleCount MVMSpeshStatsTypeTupleCount;
+typedef struct MVMSpeshStatsPluginGuardCount MVMSpeshStatsPluginGuardCount;
 typedef struct MVMSpeshStatsStatic MVMSpeshStatsStatic;
 typedef struct MVMSpeshSimStack MVMSpeshSimStack;
 typedef struct MVMSpeshSimStackFrame MVMSpeshSimStackFrame;
@@ -193,6 +197,10 @@ typedef struct MVMSpeshPlan MVMSpeshPlan;
 typedef struct MVMSpeshPlanned MVMSpeshPlanned;
 typedef struct MVMSpeshArgGuard MVMSpeshArgGuard;
 typedef struct MVMSpeshArgGuardNode MVMSpeshArgGuardNode;
+typedef struct MVMSpeshUsages MVMSpeshUsages;
+typedef struct MVMSpeshUseChainEntry MVMSpeshUseChainEntry;
+typedef struct MVMSpeshDeoptUseEntry MVMSpeshDeoptUseEntry;
+typedef struct MVMSpeshFrameWalker MVMSpeshFrameWalker;
 typedef struct MVMSTable MVMSTable;
 typedef struct MVMStaticFrame MVMStaticFrame;
 typedef struct MVMStaticFrameBody MVMStaticFrameBody;
@@ -246,16 +254,16 @@ typedef struct MVMJitInvoke MVMJitInvoke;
 typedef struct MVMJitJumpList MVMJitJumpList;
 typedef struct MVMJitControl MVMJitControl;
 typedef struct MVMJitData MVMJitData;
+typedef struct MVMJitStackSlot MVMJitStackSlot;
 typedef struct MVMJitCode MVMJitCode;
-typedef struct MVMJitExprTree MVMJitExprTree;
-typedef struct MVMJitTreeTraverser MVMJitTreeTraverser;
 typedef struct MVMJitCompiler MVMJitCompiler;
+typedef struct MVMJitExprTree MVMJitExprTree;
+typedef struct MVMJitExprInfo MVMJitExprInfo;
 typedef struct MVMJitExprTemplate MVMJitExprTemplate;
-typedef struct MVMJitExprOpInfo MVMJitExprOpInfo;
-typedef struct MVMJitExprNodeInfo MVMJitExprNodeInfo;
-typedef struct MVMJitTileTemplate MVMJitTileTemplate;
+typedef struct MVMJitTreeTraverser MVMJitTreeTraverser;
 typedef struct MVMJitTile MVMJitTile;
 typedef struct MVMJitTileList MVMJitTileList;
+typedef struct MVMJitTileTemplate MVMJitTileTemplate;
 typedef struct MVMProfileThreadData MVMProfileThreadData;
 typedef struct MVMProfileGC MVMProfileGC;
 typedef struct MVMProfileCallNode MVMProfileCallNode;
@@ -272,3 +280,10 @@ typedef struct MVMHeapSnapshotReference MVMHeapSnapshotReference;
 typedef struct MVMHeapSnapshotState MVMHeapSnapshotState;
 typedef struct MVMHeapSnapshotWorkItem MVMHeapSnapshotWorkItem;
 typedef struct MVMHeapSnapshotSeen MVMHeapSnapshotSeen;
+typedef struct MVMDebugServerBreakpointInfo MVMDebugServerBreakpointInfo;
+typedef struct MVMDebugServerBreakpointFileTable MVMDebugServerBreakpointFileTable;
+typedef struct MVMDebugServerBreakpointTable MVMDebugServerBreakpointTable;
+typedef struct MVMDebugServerHandleTable MVMDebugServerHandleTable;
+typedef struct MVMDebugServerHandleTableEntry MVMDebugServerHandleTableEntry;
+typedef struct MVMDebugServerRequestEntry MVMDebugServerRequestEntry;
+typedef struct MVMDebugServerData MVMDebugServerData;
